Multiplies every x and y coordinate by pi / 180. The geometry type of the
output matches the geometry type of the input.
Details
Only the x and y coordinates are converted. Z and M values are dropped, since the conversion goes through a two dimensional representation.
See also
Other convert:
ga_to_degrees()
Examples
deg <- ga_xy(c(0, 45), c(0, 90))
geoarrow::as_geoarrow_vctr(ga_to_radians(deg))
#> <geoarrow_vctr geoarrow.point{struct}[2]>
#> [1] <POINT (0 0)> <POINT (0.7853982 1.5707963)>